# RAMSLIBS 
## Useful tools for working with RAMS data

[![Documentation Status](https://readthedocs.org/projects/ramslibs/badge/?version=latest)](https://ramslibs.readthedocs.io/en/latest/?badge=latest)

Install with:
```
pip install ramslibs
``` 
Documentation can be [found here](https://ramslibs.readthedocs.io/en/latest)

RAMSlibs is distributed under an [MIT License](LICENSE)
